@@ -1,9 +1,16 @@
+use std::borrow::Cow;
+
+use anyhow::bail;
+use anyhow::Result;
 use dprint_core::configuration::resolve_new_line_kind;
 use dprint_core::formatting::*;
-use dprint_core::types::ErrBox;
 
 use super::configuration::Configuration;
-use super::parsing::{file_has_ignore_file_directive, parse_cmark_ast, parse_node, parse_yaml_header, Context};
+use super::generation::file_has_ignore_file_directive;
+use super::generation::generate;
+use super::generation::parse_cmark_ast;
+use super::generation::parse_yaml_header;
+use super::generation::Context;
 
 /// Formats a file.
 ///
@@ -11,8 +18,8 @@ use super::parsing::{file_has_ignore_file_directive, parse_cmark_ast, parse_node
 pub fn format_text(
   file_text: &str,
   config: &Configuration,
-  format_code_block_text: impl FnMut(&str, &str, u32) -> Result<String, ErrBox>,
-) -> Result<String, ErrBox> {
+  format_code_block_text: impl for<'a> FnMut(&str, &'a str, u32) -> Result<Cow<'a, str>>,
+) -> Result<String> {
   let (source_file, markdown_text) = match parse_source_file(file_text, config)? {
     ParseFileResult::IgnoreFile => return Ok(file_text.to_string()),
     ParseFileResult::SourceFile(file) => file,
@@ -20,8 +27,8 @@ pub fn format_text(
 
   Ok(dprint_core::formatting::format(
     || {
-      let mut context = Context::new(&markdown_text, config, format_code_block_text);
-      let print_items = parse_node(&source_file.into(), &mut context);
+      let mut context = Context::new(markdown_text, config, format_code_block_text);
+      let print_items = generate(&source_file.into(), &mut context);
       // println!("{}", print_items.get_as_text());
       print_items
     },
@@ -33,7 +40,7 @@ pub fn format_text(
 pub fn trace_file(
   file_text: &str,
   config: &Configuration,
-  format_code_block_text: Box<dyn Fn(&str, &str, u32) -> Result<String, String>>,
+  format_code_block_text: Box<dyn Fn(&str, &str, u32) -> Result<String>>,
 ) -> dprint_core::formatting::TracingResult {
   let (source_file, markdown_text) = match parse_source_file(file_text, config).unwrap() {
     ParseFileResult::IgnoreFile => panic!("Cannot trace file because it has an ignore file comment."),
@@ -52,10 +59,10 @@ pub fn trace_file(
 
 enum ParseFileResult<'a> {
   IgnoreFile,
-  SourceFile((crate::parsing::common::SourceFile, &'a str)),
+  SourceFile((crate::generation::common::SourceFile, &'a str)),
 }
 
-fn parse_source_file<'a>(file_text: &'a str, config: &Configuration) -> Result<ParseFileResult<'a>, String> {
+fn parse_source_file<'a>(file_text: &'a str, config: &Configuration) -> Result<ParseFileResult<'a>> {
   let yaml_header = parse_yaml_header(file_text); // todo: improve... this is kind of hacked into here
   let markdown_text = match &yaml_header {
     Some(yaml_header) => &file_text[yaml_header.range.end..],
@@ -63,7 +70,7 @@ fn parse_source_file<'a>(file_text: &'a str, config: &Configuration) -> Result<P
   };
 
   // check for the presence of an dprint-ignore-file comment before parsing
-  if file_has_ignore_file_directive(&markdown_text, &config.ignore_file_directive) {
+  if file_has_ignore_file_directive(markdown_text, &config.ignore_file_directive) {
     return Ok(ParseFileResult::IgnoreFile);
   }
 
@@ -73,11 +80,10 @@ fn parse_source_file<'a>(file_text: &'a str, config: &Configuration) -> Result<P
       source_file.yaml_header = yaml_header;
       Ok(ParseFileResult::SourceFile((source_file, markdown_text)))
     }
-    Err(error) => Err(dprint_core::formatting::utils::string_utils::format_diagnostic(
-      Some((error.range.start, error.range.end)),
-      &error.message,
-      file_text,
-    )),
+    Err(error) => bail!(
+      "{}",
+      dprint_core::formatting::utils::string_utils::format_diagnostic(Some((error.range.start, error.range.end)), &error.message, file_text)
+    ),
   }
 }
 
